__all__ = ['TetrahedralOrientableCuspedCensus', 'TetrahedralNonorientableCuspedCensus']

from snappy.database import ManifoldTable

class TetrahedralOrientableCuspedTable(ManifoldTable):
    """
    Iterator for the tetrahedral orientable cusped hyperbolic manifolds up to
    23 tetrahedra, i.e., manifolds that admit a tessellation by regular ideal
    hyperbolic tetrahedra as computed.
    """

    def __init__(self, **kwargs):
        return ManifoldTable.__init__(
            self,
            'tetrahedral_orientable_cusped_census',
            db_path = "tetrahedralOrientableCuspedCensus.sqlite",
            **kwargs)

TetrahedralOrientableCuspedCensus = TetrahedralOrientableCuspedTable()

class TetrahedralNonorientableCuspedTable(ManifoldTable):
    """
    Iterator for the tetrahedral non-orientable cusped hyperbolic manifolds up
    to 19 tetrahedra, i.e., manifolds that admit a tessellation by regular
    ideal hyperbolic tetrahedra as computed.
    """

    def __init__(self, **kwargs):
        return ManifoldTable.__init__(
            self,
            'tetrahedral_nonorientable_cusped_census',
            db_path = "tetrahedralNonrientableCuspedCensus.sqlite",
            **kwargs)

TetrahedralNonorientableCuspedCensus = TetrahedralNonorientableCuspedTable()
